Documentation
¶
Index ¶
- Constants
- func Eval(line string, ctx *script.ScriptContext) error
- func EvalBatch(r io.Reader, ctx *script.ScriptContext) error
- func NewScriptContext(getSession func() *session.Session, resetSession func() error, st *store.Store, ...) (script.ScriptContext, context.CancelFunc)
- type Instruction
- type Jump
Constants ¶
const ScriptHelpText = `` /* 5625-byte string literal not displayed */
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Instruction ¶
We strip out comments and blanks, so track original line# for debugging
type Jump ¶
type Jump struct {
TargetOnFalse int // If -> elif; elif -> else; while -> endwhile
TargetOnEnd int // If/elif/else -> endif; endwhile -> while; break -> endwhile; continue -> while
}
Keeps track of where the Program Counter (PC) should move next. PC is just the index of the slice of instructions. On true, we always execute the next immediate line.
Click to show internal directories.
Click to hide internal directories.